@@ -18,38 +18,35 @@
 
 #include "kftabdlg.h"
 
+#include <QApplication>
 #include <QButtonGroup>
-#include <QRadioButton>
+#include <QCheckBox>
+#include <QDesktopWidget>
+#include <QFileDialog>
 #include <QLabel>
 #include <QLayout>
-#include <QCheckBox>
 #include <QMimeDatabase>
-#include <QWhatsThis>
-
 #include <QPushButton>
-#include <QApplication>
-#include <QDesktopWidget>
-
-#include <kcalendarsystem.h>
-#include <KDateComboBox>
-#include <kglobal.h>
-#include <kcombobox.h>
-#include <kurlcombobox.h>
-#include <kurlcompletion.h>
-#include <klineedit.h>
-#include <kmessagebox.h>
+#include <QRadioButton>
 #include <QSpinBox>
-#include <QFileDialog>
-#include <kregexpeditorinterface.h>
-#include <kservicetypetrader.h>
-#include <kstandarddirs.h>
-#include <kdialog.h>
-#include <kconfiggroup.h>
-#include <KShell>
-
+#include <QStandardPaths>
+#include <QWhatsThis>
 #include <QtConcurrent/QtConcurrentRun>
 #include <QFutureWatcher>
 
+#include <KComboBox>
+#include <KConfigGroup>
+#include <KDateComboBox>
+#include <KLineEdit>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KRegExpEditorInterface>
+#include <KServiceTypeTrader>
+#include <KSharedConfig>
+#include <KShell>
+#include <KUrlComboBox>
+#include <KUrlCompletion>
+
 #include <algorithm>
 
 #include "kquery.h"
@@ -68,7 +65,7 @@ struct MimeTypes
 };
 
 KfindTabWidget::KfindTabWidget(QWidget *parent)
-    : KTabWidget(parent)
+    : QTabWidget(parent)
     , regExpDialog(nullptr)
 {
     // This validator will be used for all numeric edit fields
@@ -105,7 +102,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     caseSensCb->setChecked(false);
     useLocateCb->setChecked(false);
     hiddenFilesCb->setChecked(false);
-    if (KStandardDirs::findExe(QStringLiteral("locate")).isEmpty()) {
+    if (QStandardPaths::findExecutable(QStringLiteral("locate")).isEmpty()) {
         useLocateCb->setEnabled(false);
     }
 
@@ -147,8 +144,6 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     // Layout
 
     QGridLayout *grid = new QGridLayout(pages[0]);
-    grid->setMargin(KDialog::marginHint());
-    grid->setSpacing(KDialog::spacingHint());
     QVBoxLayout *subgrid = new QVBoxLayout();
     grid->addWidget(namedL, 0, 0);
     grid->addWidget(nameBox, 0, 1, 1, 3);
@@ -258,11 +253,8 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     // Layout
 
     QGridLayout *grid1 = new QGridLayout(pages[1]);
-    grid1->setMargin(KDialog::marginHint());
-    grid1->setSpacing(KDialog::spacingHint());
 
     grid1->addWidget(findCreated, 0, 0, 1, 3);
-    grid1->addItem(new QSpacerItem(KDialog::spacingHint(), 0), 0, 0);
 
     grid1->addWidget(rb[0], 1, 1);
     grid1->addWidget(fromDate, 1, 2);
@@ -308,7 +300,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     QLabel *typeL = new QLabel(i18nc("label for the file type combobox", "File &type:"), pages[2]);
     typeL->setBuddy(typeBox);
     textEdit = new KLineEdit(pages[2]);
-    textEdit->setClearButtonShown(true);
+    textEdit->setClearButtonEnabled(true);
     textEdit->setObjectName(QStringLiteral("textEdit"));
     QLabel *textL = new QLabel(i18n("C&ontaining text:"), pages[2]);
     textL->setBuddy(textEdit);
@@ -361,7 +353,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     typeBox->addItem(i18n("All Sounds"));
     typeBox->insertSeparator(typeBox->count()); // append separator
 
-    auto mimeTypeFuture = QtConcurrent::run([this] {
+    auto mimeTypeFuture = QtConcurrent::run([] {
         MimeTypes mimeTypes;
 
         const auto types = QMimeDatabase().allMimeTypes();
@@ -420,8 +412,6 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     sizeEdit->setMinimumSize(tmp, sizeEdit->sizeHint().height());
 
     QGridLayout *grid2 = new QGridLayout(pages[2]);
-    grid2->setMargin(KDialog::marginHint());
-    grid2->setSpacing(KDialog::spacingHint());
     grid2->addWidget(typeL, 0, 0);
     grid2->addWidget(textL, 1, 0);
     grid2->addWidget(typeBox, 0, 1, 1, 3);
@@ -507,7 +497,7 @@ void KfindTabWidget::fillDirBox()
     QDir m_dir(QStringLiteral("/lib"));
     dirBox->insertItem(0, m_url.toDisplayString());
     dirBox->addUrl(QUrl::fromLocalFile(QDir::homePath()));
-    dirBox->addUrl(QUrl::fromLocalFile("/"));
+    dirBox->addUrl(QUrl::fromLocalFile(QStringLiteral("/")));
     dirBox->addUrl(QUrl::fromLocalFile(QStringLiteral("/usr")));
     if (m_dir.exists()) {
         dirBox->addUrl(QUrl::fromLocalFile(QStringLiteral("lib")));
@@ -954,7 +944,7 @@ QSize KfindTabWidget::sizeHint() const
     // Like in minicli, we changed the combobox size policy so that they can resize down,
     // and then we simply provide a reasonable size hint for the whole window, depending
     // on the screen width.
-    QSize sz = KTabWidget::sizeHint();
+    QSize sz = QTabWidget::sizeHint();
     KfindTabWidget *me = const_cast<KfindTabWidget *>(this);
     const int screenWidth = qApp->desktop()->screenGeometry(me).width();
     if (sz.width() > screenWidth / 2) {
